/***************************************************************************
*                 _                                _                       *
*                /_\         Chess Board          /_\                      *
*                \_/      -------------------     \_/                      *
*                /_\           Settings           /_\                      *
*                |_|      -------------------     |_|                      *
*               /___\      GNU GPL Version 2     /___\                     *
*                                                                          *
***************************************************************************/
/* Header Files */
#include "setting.h"

/* Window */
static WINDOW *winM;
static WINDOW *winN;
/* File Open */
FILE *cboard;
/* Settings */
char nevent[30] = "Chess Board Match";
char nsite[30] = "GWOS";

/* Constructor */
Datum sdate;
Colour scolour;
Set::Set() {}

//-----------------------------------------------------------------------------

/* Draw Chess Board */
void Set::settings(char *ipadr, char *chess, char *white, char *black)
{
	initscr();
	winM = newwin(21,43,2,2);
	attrset(use_default_colors());
	box(winM,ACS_VLINE,ACS_HLINE);
	mvwprintw(winM, 1,2,"  | a | b | c | d | e | f | g | h |   ");
	mvwprintw(winM, 2,2,"--+---+---+---+---+---+---+---+---+---");
	mvwprintw(winM, 3,2," 8  a8  b8  c8  d8  e8  f8  g8  h8  8 ");
	mvwprintw(winM, 5,2," 7  a7  b7  c7  d7  e7  f7  g7  h7  7 ");
	mvwprintw(winM, 7,2," 6  a6  b6  c6  d6  e6  f6  g6  h6  6 ");
	mvwprintw(winM, 9,2," 5  a5  b5  c5  d5  e5  f5  g5  h5  5 ");
	mvwprintw(winM,11,2," 4  a4  b4  c4  d4  e4  f4  g4  h4  4 ");
	mvwprintw(winM,13,2," 3  a3  b3  c3  d3  e3  f3  g3  h3  3 ");
	mvwprintw(winM,15,2," 2  a2  b2  c2  d2  e2  f2  g2  h2  2 ");
	mvwprintw(winM,17,2," 1  a1  b1  c1  d1  e1  f1  g1  h1  1 ");
	mvwprintw(winM,18,2,"--+---+---+---+---+---+---+---+---+---");
	mvwprintw(winM,19,2,"  | a | b | c | d | e | f | g | h | ");
	touchwin(winM);
	wrefresh(winM);
	
	//---------------------------------------------------------------------

	/* Date */
	strftime(ndate, 75, "%Y.%m.%d", sdate.date_Board());

	/* Settings */
	board.msec = 7200;
	board.wtime = 7200;
	board.btime = 7200;
	board.nround = 0;
	board.nround++;

	scolour.color_Board();
	winN = newwin(21,31,2,46);
	wattrset(winN,A_NORMAL);
	box(winN,ACS_VLINE,ACS_HLINE);
		
	/* Chess Settings */
	mvwprintw(winN,2,2,"Event: %s",nevent);
	mvwprintw(winN,3,2,"Site:  %s",nsite);
	mvwprintw(winN,4,2,"Date:  %s",ndate);
	mvwprintw(winN,5,2,"Round: %d",board.nround);
	mvwprintw(winN,6,2,"Result: %c-%c",board.wresult,board.bresult);	
	
	//---------------------------------------------------------------------

	/* Game Settings */
	mvwprintw(winN,11,2,"Chess Clock        <     >");
	mvwprintw(winN,12,2,"UCI Protocol       <     >");
	mvwprintw(winN,13,2,"PGN File           <     >");
	mvwprintw(winN,14,2,"Network            <     >");
	wattrset(winN,COLOR_PAIR(7));
	mvwprintw(winN,11,23,"NOT");
	mvwprintw(winN,12,23,"NOT");
	mvwprintw(winN,13,23,"NOT");
	mvwprintw(winN,14,23,"NOT");
	wattrset(winN,COLOR_PAIR(6));

	//---------------------------------------------------------------------

	/* Chess Clock */
	if((board.msec == board.wtime) && (board.msec == board.btime))
	{
		mvwprintw(winN,11,23,"YES");
	}

	/* UCI Protocol */
	board.uci = true;
	board.isready = true;
	board.ucinewgame = true;

	if(board.uci)
	{
		board.uciok = true;
		mvwprintw(winN,12,23,"YES");
	}
	if(board.isready)
	{	
		board.readyok = true;
		mvwprintw(winN,12,23,"YES");
	}

	/* PGN Log File */
	cboard=fopen("/var/log/cboard/chess.pgn","r+");
	if(cboard != NULL)
	{
		mvwprintw(winN,13,23,"YES");
	}

	/* Network */
	if(chess[4] || chess[5])
	{
		mvwprintw(winN,14,23,"YES");
	}

	//---------------------------------------------------------------------

	/* Player */
	wattrset(winN,A_NORMAL);
	mvwprintw(winN,8,2,"White: ");
	wgetstr(winN, white);
	mvwprintw(winN,9,2,"Black: ");
	wgetstr(winN, black);

	/* Server IP */
	if(chess[5])
	{	
		mvwprintw(winN,16,2,"Server IP: ");
		wgetstr(winN, ipadr);
	}
	touchwin(winN);
	wrefresh(winN);
	
	//---------------------------------------------------------------------
	
	/* Write Text File */
	fprintf(cboard,"[Event \"%s\"]\n",nevent);
	fprintf(cboard,"[Site \"%s\"]\n",nsite);
	fprintf(cboard,"[Date \"%s\"]\n",ndate);
	fprintf(cboard,"[Round \"%d\"]\n",board.nround);
	fprintf(cboard,"[White \"%s\"]\n",white);	
	fprintf(cboard,"[Black \"%s\"]\n",black);
	fprintf(cboard,"[TimeControl \"%d+0\"]\n",board.msec);
	fprintf(cboard,"[Result \"%c-%c\"]\n\n",board.wresult,board.bresult);
	/* Chess File Close */
	fclose(cboard);
}

//-----------------------------------------------------------------------------

